@@ -18,7 +18,7 @@ use Pinto::ArchiveUnpacker;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.094'; # VERSION
+our $VERSION = '0.095'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -102,7 +102,8 @@ sub requires {
     my $archive = $self->archive;
     debug "Extracting packages required by archive $archive";
 
-    my $prereqs_meta = try { $self->dm->meta->prereqs } catch { throw "Unable to extract prereqs from $archive: $_" };
+    my $prereqs_meta = try { $self->dm->meta->prereqs } 
+                     catch { throw "Unable to extract prereqs from $archive: $_" };
 
     my @prereqs;
     for my $phase ( keys %{$prereqs_meta} ) {
@@ -120,6 +121,14 @@ sub requires {
         }
     }
 
+    my $base = $archive->basename;
+
+    whine "$base appears to be a bundle.  Prereqs for bundles cannot be determined automatically"
+        if $base =~ m/^ Bundle- /x;
+
+#    whine "$base uses dynamic configuration so prereqs may be incomplete"
+#        if $self->dm->meta->dynamic_config;
+
     return @prereqs;
 }
 
@@ -213,7 +222,7 @@ Pinto::PackageExtractor - Extract packages provided/required by a distribution a
 
 =head1 VERSION
 
-version 0.094
+version 0.095
 
 =head1 AUTHOR
 
